You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by tr...@apache.org on 2005/06/20 16:21:18 UTC

svn commit: r191473 - in /directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server: authn/ invocation/ jndi/ partition/

Author: trustin
Date: Mon Jun 20 07:21:16 2005
New Revision: 191473

URL: http://svn.apache.org/viewcvs?rev=191473&view=rev
Log:
Renamed PartitionNexus to ContextPartitionNexus

Added:
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/ContextPartitionNexus.java
      - copied, changed from r191472, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/PartitionNexus.java
Removed:
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/ApplicationPartition.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/PartitionNexus.java
Modified:
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/authn/AuthenticatorContext.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/authn/GenericAuthenticatorContext.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/authn/SimpleAuthenticator.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/GetMatchedDN.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/ListSuffixes.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/DefaultContextFactoryConfiguration.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/RootNexusProxy.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/ServerContext.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/ServerDirContext.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/ServerLdapContext.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/RootNexus.java

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/authn/AuthenticatorContext.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/authn/AuthenticatorContext.java?rev=191473&r1=191472&r2=191473&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/authn/AuthenticatorContext.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/authn/AuthenticatorContext.java Mon Jun 20 07:21:16 2005
@@ -19,7 +19,7 @@
 
 import org.apache.ldap.server.configuration.AuthenticatorConfiguration;
 import org.apache.ldap.server.configuration.StartupConfiguration;
-import org.apache.ldap.server.partition.PartitionNexus;
+import org.apache.ldap.server.partition.ContextPartitionNexus;
 
 
 /**
@@ -43,7 +43,7 @@
     public AuthenticatorConfiguration getConfiguration();
 
     /**
-     * Returns {@link PartitionNexus}.
+     * Returns {@link ContextPartitionNexus}.
      */
-    public PartitionNexus getPartitionNexus();
+    public ContextPartitionNexus getPartitionNexus();
 }

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/authn/GenericAuthenticatorContext.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/authn/GenericAuthenticatorContext.java?rev=191473&r1=191472&r2=191473&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/authn/GenericAuthenticatorContext.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/authn/GenericAuthenticatorContext.java Mon Jun 20 07:21:16 2005
@@ -19,7 +19,7 @@
 
 import org.apache.ldap.server.configuration.AuthenticatorConfiguration;
 import org.apache.ldap.server.configuration.StartupConfiguration;
-import org.apache.ldap.server.partition.PartitionNexus;
+import org.apache.ldap.server.partition.ContextPartitionNexus;
 
 
 /**
@@ -33,7 +33,7 @@
     private StartupConfiguration rootConfiguration;
     private AuthenticatorConfiguration configuration;
     /** the root nexus to all database partitions */
-    private PartitionNexus partitionNexus;
+    private ContextPartitionNexus partitionNexus;
 
     /**
      * Create a new AuthenticatorContext.
@@ -41,7 +41,7 @@
     public GenericAuthenticatorContext(
             StartupConfiguration rootConfiguration,
             AuthenticatorConfiguration configuration,
-            PartitionNexus partitionNexus )
+            ContextPartitionNexus partitionNexus )
     {
         this.rootConfiguration = rootConfiguration;
         this.configuration = configuration;
@@ -58,7 +58,7 @@
         return configuration;
     }
 
-    public PartitionNexus getPartitionNexus()
+    public ContextPartitionNexus getPartitionNexus()
     {
         return partitionNexus;
     }

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/authn/SimpleAuthenticator.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/authn/SimpleAuthenticator.java?rev=191473&r1=191472&r2=191473&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/authn/SimpleAuthenticator.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/authn/SimpleAuthenticator.java Mon Jun 20 07:21:16 2005
@@ -27,7 +27,7 @@
 import org.apache.ldap.common.name.LdapName;
 import org.apache.ldap.common.util.ArrayUtils;
 import org.apache.ldap.server.jndi.ServerContext;
-import org.apache.ldap.server.partition.PartitionNexus;
+import org.apache.ldap.server.partition.ContextPartitionNexus;
 
 
 /**
@@ -93,7 +93,7 @@
 
         LdapName principalDn = new LdapName( principal );
 
-        PartitionNexus rootNexus = getContext().getPartitionNexus();
+        ContextPartitionNexus rootNexus = getContext().getPartitionNexus();
 
         Attributes userEntry = rootNexus.lookup( principalDn );
 

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/GetMatchedDN.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/GetMatchedDN.java?rev=191473&r1=191472&r2=191473&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/DefaultContextFactoryConfiguration.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/DefaultContextFactoryConfiguration.java Mon Jun 20 07:21:16 2005
@@ -46,7 +46,7 @@
 import org.apache.ldap.server.invocation.Invocation;
 import org.apache.ldap.server.partition.ApplicationPartition;
 import org.apache.ldap.server.partition.ContextPartition;
-import org.apache.ldap.server.partition.PartitionNexus;
+import org.apache.ldap.server.partition.ContextPartitionNexus;
 import org.apache.ldap.server.partition.RootNexus;
 import org.apache.ldap.server.partition.store.impl.btree.DefaultSearchEngine;
 import org.apache.ldap.server.partition.store.impl.btree.ExpressionEnumerator;
@@ -96,7 +96,7 @@
     private InterceptorChain interceptorChain;
     
     /** PartitionNexus proxy wrapping nexus to inject services */
-    private final PartitionNexus proxy = new RootNexusProxy(this);
+    private final ContextPartitionNexus proxy = new RootNexusProxy(this);
 
     /** whether or not this instance has been shutdown */
     private boolean started = false;

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/RootNexusProxy.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/RootNexusProxy.java?rev=191473&r1=191472&r2=191473&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/RootNexusProxy.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/RootNexusProxy.java Mon Jun 20 07:21:16 2005
@@ -45,9 +45,9 @@
 import org.apache.ldap.server.invocation.MoveAndModifyRN;
 import org.apache.ldap.server.invocation.Search;
 import org.apache.ldap.server.partition.ContextPartition;
-import org.apache.ldap.server.partition.PartitionNexus;
+import org.apache.ldap.server.partition.ContextPartitionNexus;
 
-class RootNexusProxy implements PartitionNexus
+class RootNexusProxy implements ContextPartitionNexus
 {
     private final ContextFactoryConfiguration provider;
 

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/ServerContext.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/ServerContext.java?rev=191473&r1=191472&r2=191473&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/ServerContext.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/ServerContext.java Mon Jun 20 07:21:16 2005
@@ -45,7 +45,7 @@
 import org.apache.ldap.common.util.NamespaceTools;
 import org.apache.ldap.server.authn.AuthenticationService;
 import org.apache.ldap.server.authn.LdapPrincipal;
-import org.apache.ldap.server.partition.PartitionNexus;
+import org.apache.ldap.server.partition.ContextPartitionNexus;
 
 
 /**
@@ -60,7 +60,7 @@
     public static final String DELETE_OLD_RDN_PROP = "java.naming.ldap.deleteRDN";
 
     /** The interceptor proxy to the backend nexus */
-    private final PartitionNexus nexusProxy;
+    private final ContextPartitionNexus nexusProxy;
 
     /** The cloned environment used by this Context */
     private final Hashtable env;
@@ -90,7 +90,7 @@
      * @throws NamingException if the environment parameters are not set 
      * correctly.
      */
-    protected ServerContext( PartitionNexus nexusProxy, Hashtable env ) throws NamingException
+    protected ServerContext( ContextPartitionNexus nexusProxy, Hashtable env ) throws NamingException
     {
         String url;
 
@@ -142,7 +142,7 @@
      * @param env the environment properties used by this context
      * @param dn the distinguished name of this context
      */
-    protected ServerContext( LdapPrincipal principal, PartitionNexus nexusProxy, Hashtable env, Name dn )
+    protected ServerContext( LdapPrincipal principal, ContextPartitionNexus nexusProxy, Hashtable env, Name dn )
     {
         this.dn = ( LdapName ) dn.clone();
 
@@ -193,7 +193,7 @@
      * 
      * @return the proxy to the backend nexus.
      */
-    protected PartitionNexus getNexusProxy()
+    protected ContextPartitionNexus getNexusProxy()
     {
        return nexusProxy ;
     }

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/ServerDirContext.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/ServerDirContext.java?rev=191473&r1=191472&r2=191473&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/ServerDirContext.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/ServerDirContext.java Mon Jun 20 07:21:16 2005
@@ -46,7 +46,7 @@
 import org.apache.ldap.common.name.LdapName;
 import org.apache.ldap.common.util.NamespaceTools;
 import org.apache.ldap.server.authn.LdapPrincipal;
-import org.apache.ldap.server.partition.PartitionNexus;
+import org.apache.ldap.server.partition.ContextPartitionNexus;
 
 
 /**
@@ -71,7 +71,7 @@
      * @param env the environment used for this context
      * @throws NamingException if something goes wrong
      */
-    public ServerDirContext( PartitionNexus nexusProxy, Hashtable env ) throws NamingException
+    public ServerDirContext( ContextPartitionNexus nexusProxy, Hashtable env ) throws NamingException
     {
         super( nexusProxy, env );
     }
@@ -86,7 +86,7 @@
      * @param env the environment properties used by this context
      * @param dn the distinguished name of this context
      */
-    protected ServerDirContext( LdapPrincipal principal, PartitionNexus nexusProxy, Hashtable env, Name dn )
+    protected ServerDirContext( LdapPrincipal principal, ContextPartitionNexus nexusProxy, Hashtable env, Name dn )
     {
         super( principal, nexusProxy, env, dn );
     }

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/ServerLdapContext.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/ServerLdapContext.java?rev=191473&r1=191472&r2=191473&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/ServerLdapContext.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/ServerLdapContext.java Mon Jun 20 07:21:16 2005
@@ -28,7 +28,7 @@
 
 import org.apache.ldap.common.NotImplementedException;
 import org.apache.ldap.server.authn.LdapPrincipal;
-import org.apache.ldap.server.partition.PartitionNexus;
+import org.apache.ldap.server.partition.ContextPartitionNexus;
 
 
 /**
@@ -52,7 +52,7 @@
      * @param env the JNDI environment parameters
      * @throws NamingException the context cannot be created
      */
-    public ServerLdapContext( PartitionNexus nexusProxy, Hashtable env ) throws NamingException
+    public ServerLdapContext( ContextPartitionNexus nexusProxy, Hashtable env ) throws NamingException
     {
         super( nexusProxy, env );
     }
@@ -67,7 +67,7 @@
      * @param env the environment properties used by this context
      * @param dn the distinguished name of this context
      */
-    ServerLdapContext( LdapPrincipal principal, PartitionNexus nexusProxy, Hashtable env, Name dn )
+    ServerLdapContext( LdapPrincipal principal, ContextPartitionNexus nexusProxy, Hashtable env, Name dn )
     {
         super( principal, nexusProxy, env, dn );
     }

Copied: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/ContextPartitionNexus.java (from r191472, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/PartitionNexus.java)
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/ContextPartitionNexus.java?p2=directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/ContextPartitionNexus.java&p1=directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/PartitionNexus.java&r1=191472&r2=191473&rev=191473&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/PartitionNexus.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/ContextPartitionNexus.java Mon Jun 20 07:21:16 2005
@@ -43,7 +43,7 @@
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$
  */
-public interface PartitionNexus extends ContextPartition
+public interface ContextPartitionNexus extends ContextPartition
 {
     /**
      * Gets the LdapContext associated with the calling thread.

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/RootNexus.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/RootNexus.java?rev=191473&r1=191472&r2=191473&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/RootNexus.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/RootNexus.java Mon Jun 20 07:21:16 2005
@@ -54,7 +54,7 @@
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$
  */
-public class RootNexus implements PartitionNexus
+public class RootNexus implements ContextPartitionNexus
 {
     /** the vendorName string proudly set to: Apache Software Foundation*/
     private static final String ASF = "Apache Software Foundation";
@@ -123,7 +123,7 @@
     
 
     /**
-     * @see PartitionNexus#getLdapContext()
+     * @see ContextPartitionNexus#getLdapContext()
      */
     public LdapContext getLdapContext() 
     {
@@ -132,7 +132,7 @@
 
 
     /**
-     * @see PartitionNexus#getMatchedDn(javax.naming.Name, boolean)
+     * @see ContextPartitionNexus#getMatchedDn(javax.naming.Name, boolean)
      */
     public Name getMatchedDn( Name dn, boolean normalized ) throws NamingException
     {
@@ -153,7 +153,7 @@
 
 
     /**
-     * @see org.apache.ldap.server.partition.PartitionNexus#getSuffix(javax.naming.Name, boolean)
+     * @see org.apache.ldap.server.partition.ContextPartitionNexus#getSuffix(javax.naming.Name, boolean)
      */
     public Name getSuffix( Name dn, boolean normalized ) throws NamingException
     {
@@ -164,7 +164,7 @@
 
 
     /**
-     * @see org.apache.ldap.server.partition.PartitionNexus#listSuffixes(boolean)
+     * @see org.apache.ldap.server.partition.ContextPartitionNexus#listSuffixes(boolean)
      */
     public Iterator listSuffixes( boolean normalized ) throws NamingException
     {
@@ -184,7 +184,7 @@
 
 
     /**
-     * @see org.apache.ldap.server.partition.PartitionNexus#register(
+     * @see org.apache.ldap.server.partition.ContextPartitionNexus#register(
      * ContextPartition)
      */
     public void register( ContextPartition backend )
@@ -198,7 +198,7 @@
 
 
     /**
-     * @see PartitionNexus#unregister(
+     * @see ContextPartitionNexus#unregister(
      * ContextPartition)
      */
     public void unregister( ContextPartition backend )
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/GetMatchedDN.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/GetMatchedDN.java Mon Jun 20 07:21:16 2005
@@ -21,11 +21,11 @@
 import javax.naming.NamingException;
 
 import org.apache.ldap.server.partition.ContextPartition;
-import org.apache.ldap.server.partition.PartitionNexus;
+import org.apache.ldap.server.partition.ContextPartitionNexus;
 
 
 /**
  * Represents an {@link Invocation} on {@link PartitionNexus#getMatchedDn(Name, boolean)}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
@@ -52,6 +52,6 @@
 
     protected Object doExecute( ContextPartition store ) throws NamingException
     {
-        return ( ( PartitionNexus ) store ).getMatchedDn( getName(), isNormalized() );
+        return ( ( ContextPartitionNexus ) store ).getMatchedDn( getName(), isNormalized() );
     }
 }
@@ -21,11 +21,11 @@
 
 /**
- * Represents an {@link Invocation} on {@link PartitionNexus#getMatchedDn(Name, boolean)}.
+ * Represents an {@link Invocation} on {@link ContextPartitionNexus#getMatchedDn(Name, boolean)}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/ListSuffixes.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/ListSuffixes.java?rev=191473&r1=191472&r2=191473&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/ListSuffixes.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/ListSuffixes.java Mon Jun 20 07:21:16 2005
@@ -20,11 +20,11 @@
 import javax.naming.NamingException;
 
 import org.apache.ldap.server.partition.ContextPartition;
-import org.apache.ldap.server.partition.PartitionNexus;
+import org.apache.ldap.server.partition.ContextPartitionNexus;
 
 
 /**
  * Represents an {@link Invocation} on {@link PartitionNexus#listSuffixes(boolean)}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
@@ -50,6 +50,6 @@
 
     protected Object doExecute( ContextPartition store ) throws NamingException
     {
-        return ( ( PartitionNexus ) store ).listSuffixes( normalized );
+        return ( ( ContextPartitionNexus ) store ).listSuffixes( normalized );
     }
 }
@@ -20,11 +20,11 @@
 
 /**
- * Represents an {@link Invocation} on {@link PartitionNexus#listSuffixes(boolean)}.
+ * Represents an {@link Invocation} on {@link ContextPartitionNexus#listSuffixes(boolean)}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/DefaultContextFactoryConfiguration.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/DefaultContextFactoryConfiguration.java?rev=191473&r1=191472&r2=191473&view=diff
==============================================================================